@@ -330,14 +330,14 @@ class Get_Keyword_Info(Qimai_Diy_Var):
         self.keyword_serch_index = res.json()
         return self.keyword_serch_index
 
-    def get_keyword_WordInfo(self):
+    def get_keyword_wordinfo(self):
         url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s&edate=%s' %(self.device, self.country, self.keyword, self.version, self.run_time, self.search_type, self.status, self.run_time-self.one_day)
         res = session.get(url, headers=headers)
         self.keyword_WordInfo = res.json()
         return self.keyword_WordInfo
 
     def get_keyword_hints(self):
-        self.get_keyword_WordInfo()
+        self.get_keyword_wordinfo()
         self.hints = self.keyword_WordInfo['wordInfo']['hints']
         return self.hints
 
