@@ -3,7 +3,7 @@ from qm_spider import *
 
 
 class Send_Mail:
-    def __init__(self, subject, mail_text, file_path, send_user, send_userpwd, receivers=('1013373636@qq.com')):
+    def __init__(self, subject, mail_text, file_path, send_user, send_userpwd, receivers=('ctrlf4@yeah.net')):
         self.subject = subject
         self.mail_text = mail_text
         self.file_path = file_path
